
Changelog
=========

0.2.0 (2022-05-06)
------------------

* Allow images to overlap by using alpha composition. Useful when cell is smaller than images, and images are transparent.
* Restructure template context. **BACKWARDS INCOMPATIBLE**

0.1.1 (2022-04-18)
------------------

* Remove the universal flag (don't produce py2.py3 wheels since
  py2 isn't supported anyway).

0.1.0 (2022-04-18)
------------------

* First release on PyPI.
